//
//  OCXMLParser.m
//  XML
//
//  Created by Manfred Kress on 21.06.10.
//  Copyright 2010 ObjectiveCeeds. All rights reserved.
//

#import "OCXMLParser.h"


@implementation OCXMLParser

@synthesize parser = _OCParser;

- (id) initWithXMLData: (NSData *)xml
{
	self = [super init];
	if (self != nil) {
		
		NSXMLParser *theParser = [[NSXMLParser alloc] initWithData: xml];
		[theParser setDelegate: self];
		[self setParser: theParser];
		[theParser release];
		
		[[self parser] parse];
	}
	return self;
}

- (id) init
{
		return nil;
}

- (void) dealloc
{
	[self setParser: nil];
	
	[super dealloc];
}

@end

@implementation OCXMLParser (ParserDelegate)

- (void)parserDidStartDocument:(NSXMLParser *)parser
{
	NSLog(@"Starting...");
}

- (void)parserDidEndDocument:(NSXMLParser *)parser
{
	NSLog(@"Ended.");
}


- (void)parser:(NSXMLParser *)parser didStartElement:(NSString *)elementName namespaceURI:(NSString *)namespaceURI qualifiedName:(NSString *)qName attributes:(NSDictionary *)attributeDict
{
	NSLog(@"Start Element: %@", elementName);
}

- (void)parser:(NSXMLParser *)parser didEndElement:(NSString *)elementName namespaceURI:(NSString *)namespaceURI qualifiedName:(NSString *)qName
{
	NSLog(@"End Element: %@", elementName);
}

//- (void)parser:(NSXMLParser *)parser didStartMappingPrefix:(NSString *)prefix toURI:(NSString *)namespaceURI;
// sent when the parser first sees a namespace attribute.
// In the case of the cvslog tag, before the didStartElement:, you'd get one of these with prefix == @"" and namespaceURI == @"http://xml.apple.com/cvslog" (i.e. the default namespace)
// In the case of the radar:radar tag, before the didStartElement: you'd get one of these with prefix == @"radar" and namespaceURI == @"http://xml.apple.com/radar"

//- (void)parser:(NSXMLParser *)parser didEndMappingPrefix:(NSString *)prefix;
// sent when the namespace prefix in question goes out of scope.

- (void)parser:(NSXMLParser *)parser foundCharacters:(NSString *)string
{
	NSLog(@"Characters %@" , string);
}
// This returns the string of the characters encountered thus far. You may not necessarily get the longest character run. The parser reserves the right to hand these to the delegate as potentially many calls in a row to -parser:foundCharacters:

//- (void)parser:(NSXMLParser *)parser foundIgnorableWhitespace:(NSString *)whitespaceString;
// The parser reports ignorable whitespace in the same way as characters it's found.

//- (void)parser:(NSXMLParser *)parser foundProcessingInstructionWithTarget:(NSString *)target data:(NSString *)data;
// The parser reports a processing instruction to you using this method. In the case above, target == @"xml-stylesheet" and data == @"type='text/css' href='cvslog.css'"

- (void)parser:(NSXMLParser *)parser foundComment:(NSString *)comment
{
	NSLog(@"Found Comment %@" , comment);
}

- (void)parser:(NSXMLParser *)parser foundCDATA:(NSData *)CDATABlock
{
	NSLog(@"Found Data with len %d", [CDATABlock length]);
}
// this reports a CDATA block to the delegate as an NSData.

//- (NSData *)parser:(NSXMLParser *)parser resolveExternalEntityName:(NSString *)name systemID:(NSString *)systemID;
// this gives the delegate an opportunity to resolve an external entity itself and reply with the resulting data.

- (void)parser:(NSXMLParser *)parser parseErrorOccurred:(NSError *)parseError
{
	NSLog(@"Error %@" , parseError);
}
//- (void)parser:(NSXMLParser *)parser validationErrorOccurred:(NSError *)validationError;
// If validation is on, this will report a fatal validation error to the delegate. The parser will stop parsing.
@end