//
//  OCXMLParser.m
//  XML
//
//  Created by Manfred Kress on 21.06.10.
//  Copyright 2010 ObjectiveCeeds. All rights reserved.
//

#import "OCXMLParser.h"


@implementation OCXMLParser

@synthesize parser = _OCParser;
@synthesize delegate = _OCDelegate;

- (id) initWithXMLData: (NSData *)xml delegate: (id<OCXMLParserDelegate>)delegate;
{
	if (xml == nil || delegate == nil) return nil;
	
	
	self = [super init];
	if (self != nil) {
		
		NSXMLParser *theParser = [[NSXMLParser alloc] initWithData: xml];
		[theParser setDelegate: self];
		[self setParser: theParser];
		[theParser release];
		
		[self setDelegate: delegate];
		
		[[self parser] parse];
	}
	return self;
}

- (id) init
{
		return nil;
}

- (void) dealloc
{
	[self setParser: nil];
	[self setDelegate: nil];
	
	[super dealloc];
}

@end

@implementation OCXMLParser (ParserDelegate)

- (void)parserDidStartDocument:(NSXMLParser *)parser
{
	NSLog(@"Starting...");
}

- (void)parserDidEndDocument:(NSXMLParser *)parser
{
	[[self delegate] parserDidEnd: self];
}


- (void)parser:(NSXMLParser *)parser didStartElement:(NSString *)elementName namespaceURI:(NSString *)namespaceURI qualifiedName:(NSString *)qName attributes:(NSDictionary *)attributeDict
{
	//NSLog(@"Start Element: %@", elementName);
}

- (void)parser:(NSXMLParser *)parser didEndElement:(NSString *)elementName namespaceURI:(NSString *)namespaceURI qualifiedName:(NSString *)qName
{
	//NSLog(@"End Element: %@", elementName);
}

- (void)parser:(NSXMLParser *)parser foundCharacters:(NSString *)string
{
	//NSLog(@"Characters %@" , string);
}

- (void)parser:(NSXMLParser *)parser foundIgnorableWhitespace:(NSString *)whitespaceString
{
	//NSLog(@"Ignorable whitespace %@", whitespaceString);
}

- (void)parser:(NSXMLParser *)parser foundComment:(NSString *)comment
{
	//NSLog(@"Found Comment %@" , comment);
}

- (void)parser:(NSXMLParser *)parser foundCDATA:(NSData *)CDATABlock
{
	//NSLog(@"Found Data with len %d", [CDATABlock length]);
}

- (void)parser:(NSXMLParser *)parser parseErrorOccurred:(NSError *)parseError
{
	NSLog(@"Error %@" , parseError);
}
- (void)parser:(NSXMLParser *)parser validationErrorOccurred:(NSError *)validationError
{
	NSLog(@"Validation error %@", validationError);
}

- (void)parser:(NSXMLParser *)parser foundElementDeclarationWithName:(NSString *)elementName model:(NSString *)model
{
	NSLog(@"Declaration name %@ model %@", elementName, model);
}

- (void)parser:(NSXMLParser *)parser foundAttributeDeclarationWithName:(NSString *)attributeName forElement:(NSString *)elementName type:(NSString *)type defaultValue:(NSString *)defaultValue
{
	NSLog(@"Attribute declaration %@ element %@ type %@", attributeName, elementName, type);
}
@end