//
//  OCXMLParser.m
//  XML
//
//  Created by Manfred Kress on 21.06.10.
//  Copyright 2010 ObjectiveCeeds. All rights reserved.
//

#import "OCXMLParser.h"


@implementation OCXMLParser

@synthesize parser = _OCParser;
@synthesize delegate = _OCDelegate;

@synthesize stack = _OCStack;
@synthesize buffer = _OCBuffer;
@synthesize stringBuffer = _OCStringBuffer;

- (id) initWithXMLData: (NSData *)xml delegate: (id<OCXMLParserDelegate>)delegate;
{
	if (xml == nil || delegate == nil) return nil;
	
	
	self = [super init];
	if (self != nil) {
		
		NSXMLParser *theParser = [[NSXMLParser alloc] initWithData: xml];
		[theParser setDelegate: self];
		[self setParser: theParser];
		[theParser release];
		
		NSMutableData *d =[[NSMutableData alloc] init];
		[self setBuffer: d];
		[d release];
		
		NSMutableString *s = [[NSMutableString alloc] init];
		[self setStringBuffer: s];
		[s release];		
		
		NSMutableArray *a = [[NSMutableArray alloc] init];
		[self setStack: a];
		[a release];
		
		[self setDelegate: delegate];
		
		//Add root element
		OCXMLNode *root = [[OCXMLNode alloc] init];
		[root setElementName: @"__OCROOT"];
		[[self stack] addObject: root];
		[root release];
				
		[[self parser] parse];
	}
	return self;
}

- (id) init
{
		return nil;
}

- (void) dealloc
{
	[self setParser: nil];
	[self setDelegate: nil];
	
	[self setBuffer: nil];
	[self setStringBuffer: nil];
	[self setStack: nil];
	
	[super dealloc];
}

@end

@implementation OCXMLParser (ParserDelegate)

- (void)parserDidStartDocument:(NSXMLParser *)parser
{
	//NSLog(@"Starting...");
}

- (void)parserDidEndDocument:(NSXMLParser *)parser
{
	NSLog(@"end stack %@", [self stack]);
	
	[[self delegate] parserDidEnd: self];
}


- (void)parser:(NSXMLParser *)parser didStartElement:(NSString *)elementName namespaceURI:(NSString *)namespaceURI qualifiedName:(NSString *)qName attributes:(NSDictionary *)attributeDict
{
	//NSLog(@"Start Element: %@ %@ %@", elementName, namespaceURI, attributeDict);
	
	OCXMLNode *new = [[OCXMLNode alloc] init];
	[new setElementName: elementName];
	[[new attributes] addEntriesFromDictionary: attributeDict];
	
	// become child of the enclosing  node...
	OCXMLNode *enclosing = [[self stack] lastObject];
	[[enclosing childElements] addObject: new];
	
	// become first responder...
	[[self stack] addObject: new];
	
	// release new
	[new release];
}

- (void)parser:(NSXMLParser *)parser didEndElement:(NSString *)elementName namespaceURI:(NSString *)namespaceURI qualifiedName:(NSString *)qName
{
	//NSLog(@"End Element: %@", elementName);
	
	//OCXMLNode *last = [[self stack] lastObject];
	//NSLog(@"last %@", last);
	[[self stack] removeLastObject];
}

- (void)parser:(NSXMLParser *)parser foundCharacters:(NSString *)string
{
	NSLog(@"Characters %@" , string);
}

- (void)parser:(NSXMLParser *)parser foundIgnorableWhitespace:(NSString *)whitespaceString
{
	//NSLog(@"Ignorable whitespace %@", whitespaceString);
}

- (void)parser:(NSXMLParser *)parser foundComment:(NSString *)comment
{
	//NSLog(@"Found Comment %@" , comment);
}

- (void)parser:(NSXMLParser *)parser foundCDATA:(NSData *)CDATABlock
{
	//NSLog(@"Found Data with len %d", [CDATABlock length]);
}

- (void)parser:(NSXMLParser *)parser parseErrorOccurred:(NSError *)parseError
{
	NSLog(@"Error %@" , parseError);
}
- (void)parser:(NSXMLParser *)parser validationErrorOccurred:(NSError *)validationError
{
	NSLog(@"Validation error %@", validationError);
}

- (void)parser:(NSXMLParser *)parser foundElementDeclarationWithName:(NSString *)elementName model:(NSString *)model
{
	//NSLog(@"Declaration name %@ model %@", elementName, model);
}

- (void)parser:(NSXMLParser *)parser foundAttributeDeclarationWithName:(NSString *)attributeName forElement:(NSString *)elementName type:(NSString *)type defaultValue:(NSString *)defaultValue
{
	//NSLog(@"Attribute declaration %@ element %@ type %@", attributeName, elementName, type);
}
@end