//
//  OCPostRequest.m
//  Webservices
//
//  Created by Manfred Kress on 22.01.10.
//  Copyright 2010 ObjectiveCeeds. All rights reserved.
//

#import "OCPostRequest.h"

NSString * const kOHTTPPostMethod = @"POST";

@interface OCPostRequest (Private)

- (void) setRequest: (NSMutableURLRequest *)request;
- (void) setError: (NSError *)value;

@end

@implementation OCPostRequest

@synthesize request = _OCURLRequest;
@synthesize error = _OCError;

@dynamic URLString;
@dynamic postBody;

- (id) init
{
	self = [super init];
	if (self != nil) {
		
		NSMutableURLRequest *theRequest = [[NSMutableURLRequest alloc] init];
		[theRequest setHTTPMethod: kOHTTPPostMethod];
		[self setRequest: theRequest];
		[theRequest release];
		
		[self setError: nil];
	}
	return self;
}

- (void) dealloc
{
	[self setRequest: nil];
	[self setError: nil];
	
	[super dealloc];
}

- (void) setURLString:(NSString *)value
{
	if (value == nil)
	{
		[[self request] setURL: nil];
		return;
	}
	NSURL *url = [[NSURL alloc] initWithString: value];
	[[self request] setURL: url];
	[url release];
}

- (NSString *) URLString
{
	return [[[self request] URL] absoluteString];
}

- (void) setPostBody:(NSData *)value
{
	[[self request] setHTTPBody: value];
}

- (NSData *) postBody
{
	return [[self request] HTTPBody];
}

- (NSData *) sendSynchronous
{
	if ([[self request] URL] == nil)
	{
		NSLog(@"%@ Error: Missing URL", NSStringFromClass( [self class]));
		return nil;
	}
	
	if ([self postBody] == nil)
	{
		[self setPostBody: [NSData data]];
	}
	
	NSURLResponse *response;
	NSError *theError = nil;
	NSData *result = [NSURLConnection sendSynchronousRequest: [self request]
											 returningResponse: &response
														 error: &theError];
	if (theError != nil)
	{
		[self setError: theError];
		return nil;
	}
	return result;
}

@end

@implementation OCPostRequest (Private)

- (void) setRequest: (NSMutableURLRequest *)request
{
	[request retain];
	[_OCURLRequest release];
	_OCURLRequest = request;
}

- (void) setError: (NSError *)value
{
	[value retain];
	[_OCError release];
	_OCError = value;
}
@end

